package com.plutext.samples.ole;
/*
 *  Copyright 2013, Plutext Pty Ltd.
 *   
 *  This sample file is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */




import java.io.File;

import org.apache.commons.io.FileUtils;
import org.docx4j.openpackaging.packages.WordprocessingMLPackage;
import org.docx4j.openpackaging.parts.WordprocessingML.MainDocumentPart;
import org.docx4j.wml.P;
import org.docx4j.wml.R;

import com.plutext.ole.EmbeddingType;
import com.plutext.ole.OleHelperDocx;

/**
 * Example of how to link or embed a WAV audio
 * as an OleObjectBinaryPart inside a docx  
 * 
 * @author Jason Harrop
 */
public class Docx_ole_wav  {

	static org.docx4j.wml.ObjectFactory wmlObjectFactory = org.docx4j.jaxb.Context.getWmlObjectFactory();
	
	public static void main(String[] args) throws Exception {
		
		
		////////////////////////////////////////////////////////
		// For this sample, create a docx package using docx4j

		WordprocessingMLPackage wordMLPackage = WordprocessingMLPackage.createPackage();
		MainDocumentPart mdp = wordMLPackage.getMainDocumentPart();

		
		////////////////////////////////////////////////////////
		// OLE config

		EmbeddingType embeddingType = EmbeddingType.WAV; 

		// Link or embed?
		boolean OLE_LINK_ONLY = false;
		
		// Embed
		byte[] contentBytes = FileUtils.readFileToByteArray(
        		new File(System.getProperty("user.dir")+ "/sample.wav"));
		
		// the image on the document surface
		byte[] imageBytes = null; //IconGenerator.createIcon(embeddingType, caption);
				// if imageBytes was null, IconGenerator would be used like that anyway
		
		// position in docx content list
		int index = -1; // place at end
				
		// Both link and embed require this
		String caption = "sounds"; // can be anything
        String filepath = "C:\\Users\\jharrop\\git\\docx4j-OLE\\sample.wav";    // typically the original file location
		String command ="C:\\Users\\jharrop\\git\\docx4j-OLE\\sample.wav";  // for embed case, Word uses a tmp file location. But link case points to the original file
		
        // For link only
		String targetURL = "file:///" + command;

		
		////////////////////////////////////////////////////////
		// Perform OLE
		
		P p = new P();
		if (index < 0) {
			mdp.getContents().getContent().add(p);
		} else {
			mdp.getContents().getContent().add(index, p);			
		}
		
		OleHelperDocx OleHelperDocx = new OleHelperDocx(wordMLPackage);
		if (OLE_LINK_ONLY) {
			
			R r = OleHelperDocx.link( embeddingType, caption, filepath, command, targetURL, imageBytes);
			p.getContent().add(r);

		    // Save the resulting docx
			wordMLPackage.save(new File(System.getProperty("user.dir")
					+ "/OUT_wav_linked.docx"));
			
		} else {
			
			R r = OleHelperDocx.embed( embeddingType, 
					caption, filepath, command, 
					contentBytes, imageBytes);
			p.getContent().add(r);

		    // Save the resulting docx
			wordMLPackage.save(new File(System.getProperty("user.dir")
					+ "/OUT_wav_embedded.docx"));
			
		}

						
	}
	
	
}
